@@ -100,8 +100,9 @@ struct _PopplerDocumentClass
 G_DEFINE_TYPE (PopplerDocument, poppler_document, G_TYPE_OBJECT)
 
 static PopplerDocument *
-_poppler_document_new_from_pdfdoc (PDFDoc  *newDoc,
-                                   GError **error)
+_poppler_document_new_from_pdfdoc (GlobalParamsIniter *initer,
+                                   PDFDoc             *newDoc,
+                                   GError             **error)
 {
   PopplerDocument *document;
 
@@ -145,6 +146,7 @@ _poppler_document_new_from_pdfdoc (PDFDoc  *newDoc,
   }
 
   document = (PopplerDocument *) g_object_new (POPPLER_TYPE_DOCUMENT, nullptr);
+  document->initer = initer;
   document->doc = newDoc;
 
   document->output_dev = new CairoOutputDev ();
@@ -191,9 +193,7 @@ poppler_document_new_from_file (const char  *uri,
   GooString *password_g;
   char *filename;
 
-  if (!globalParams) {
-    globalParams = std::make_unique<GlobalParams>();
-  }
+  auto initer = new GlobalParamsIniter(_poppler_error_cb);
 
   filename = g_filename_from_uri (uri, nullptr, error);
   if (!filename)
@@ -224,7 +224,7 @@ poppler_document_new_from_file (const char  *uri,
 
   delete password_g;
 
-  return _poppler_document_new_from_pdfdoc (newDoc, error);
+  return _poppler_document_new_from_pdfdoc (initer, newDoc, error);
 }
 
 /**
@@ -253,9 +253,7 @@ poppler_document_new_from_data (char        *data,
   MemStream *str;
   GooString *password_g;
 
-  if (!globalParams) {
-    globalParams = std::make_unique<GlobalParams>();
-  }
+  auto initer = new GlobalParamsIniter(_poppler_error_cb);
   
   // create stream
   str = new MemStream(data, 0, length, Object(objNull));
@@ -264,7 +262,7 @@ poppler_document_new_from_data (char        *data,
   newDoc = new PDFDoc(str, password_g, password_g);
   delete password_g;
 
-  return _poppler_document_new_from_pdfdoc (newDoc, error);
+  return _poppler_document_new_from_pdfdoc (initer, newDoc, error);
 }
 
 class BytesStream : public MemStream
@@ -307,9 +305,7 @@ poppler_document_new_from_bytes (GBytes      *bytes,
   g_return_val_if_fail(bytes != nullptr, nullptr);
   g_return_val_if_fail(error == nullptr || *error == nullptr, nullptr);
 
-  if (!globalParams) {
-    globalParams = std::make_unique<GlobalParams>();
-  }
+  auto initer = new GlobalParamsIniter(_poppler_error_cb);
 
   // create stream
   str = new BytesStream(bytes, Object(objNull));
@@ -318,7 +314,7 @@ poppler_document_new_from_bytes (GBytes      *bytes,
   newDoc = new PDFDoc(str, password_g, password_g);
   delete password_g;
 
-  return _poppler_document_new_from_pdfdoc (newDoc, error);
+  return _poppler_document_new_from_pdfdoc (initer, newDoc, error);
 }
 
 static inline gboolean
@@ -360,9 +356,7 @@ poppler_document_new_from_stream (GInputStream *stream,
   g_return_val_if_fail(G_IS_INPUT_STREAM(stream), NULL);
   g_return_val_if_fail(length == (goffset)-1 || length > 0, NULL);
 
-  if (!globalParams) {
-    globalParams = std::make_unique<GlobalParams>();
-  }
+  auto initer = new GlobalParamsIniter(_poppler_error_cb);
 
   if (!G_IS_SEEKABLE(stream) || !g_seekable_can_seek(G_SEEKABLE(stream))) {
     g_set_error_literal(error, G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED,
@@ -388,7 +382,7 @@ poppler_document_new_from_stream (GInputStream *stream,
   newDoc = new PDFDoc(str, password_g, password_g);
   delete password_g;
 
-  return _poppler_document_new_from_pdfdoc (newDoc, error);
+  return _poppler_document_new_from_pdfdoc (initer, newDoc, error);
 }
 
 /**
@@ -548,6 +542,7 @@ poppler_document_finalize (GObject *object)
   poppler_document_layers_free (document);
   delete document->output_dev;
   delete document->doc;
+  delete document->initer;
 
   G_OBJECT_CLASS (poppler_document_parent_class)->finalize (object);
 }
@@ -2609,13 +2604,7 @@ static gchar *
 unicode_to_char (const Unicode *unicode,
 		 int      len)
 {
-	static UnicodeMap *uMap = nullptr;
-	if (uMap == nullptr) {
-		GooString *enc = new GooString("UTF-8");
-		uMap = globalParams->getUnicodeMap(enc);
-		uMap->incRefCnt ();
-		delete enc;
-	}
+	const UnicodeMap *uMap = globalParams->getUtf8Map();
 		
 	GooString gstr;
 	gchar buf[8]; /* 8 is enough for mapping an unicode char to a string */
