@@ -17,15 +17,15 @@
 #define DCTSTREAM_H
 
 #include "poppler-config.h"
-#include <stdio.h>
-#include <stdlib.h>
-#include <stddef.h>
-#include <setjmp.h>
+#include <cstdio>
+#include <cstdlib>
+#include <cstddef>
+#include <csetjmp>
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
-#include <string.h>
-#include <ctype.h>
+#include <cstring>
+#include <cctype>
 #include "goo/gmem.h"
 #include "goo/gfile.h"
 #include "Error.h"
@@ -56,7 +56,7 @@ class DCTStream: public FilterStream {
 public:
 
   DCTStream(Stream *strA, int colorXformA, Dict *dict, int recursion);
-  ~DCTStream();
+  ~DCTStream() override;
   StreamKind getKind() const override { return strDCT; }
   void reset() override;
   int getChar() override;
