@@ -27,6 +27,7 @@
 // Copyright (C) 2013, 2018 Adam Reichold <adamreichold@myopera.com>
 // Copyright (C) 2013 Pino Toscano <pino@kde.org>
 // Copyright (C) 2019 Volker Krause <vkrause@kde.org>
+// Copyright (C) 2019 Alexander Volkov <a.volkov@rusbitech.ru>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -276,7 +277,7 @@ class FileOutStream : public OutStream {
 public:
   FileOutStream (FILE* fa, Goffset startA);
 
-  ~FileOutStream ();
+  ~FileOutStream () override;
 
   void close() override;
 
@@ -303,7 +304,7 @@ public:
 
     // TODO Mirar si puedo hacer que dictA sea un puntero
   BaseStream(Object &&dictA, Goffset lengthA);
-  ~BaseStream();
+  ~BaseStream() override;
   virtual BaseStream *copy() = 0;
   virtual Stream *makeSubStream(Goffset start, bool limited,
 				Goffset length, Object &&dict) = 0;
@@ -326,6 +327,63 @@ protected:
   Object dict;
 };
 
+//------------------------------------------------------------------------
+// BaseInputStream
+//------------------------------------------------------------------------
+
+class BaseSeekInputStream: public BaseStream {
+public:
+
+  // This enum is used to tell the seek() method how it must reposition
+  // the stream offset.
+  enum SeekType {
+    SeekSet, // the offset is set to offset bytes
+    SeekCur, // the offset is set to its current location plus offset bytes
+    SeekEnd  // the offset is set to the size of the stream plus offset bytes
+  };
+
+  BaseSeekInputStream(Goffset startA, bool limitedA, Goffset lengthA, Object &&dictA);
+  ~BaseSeekInputStream() override;
+  StreamKind getKind() const override { return strWeird; }
+  void reset() override;
+  void close() override;
+  int getChar() override
+    { return (bufPtr >= bufEnd && !fillBuf()) ? EOF : (*bufPtr++ & 0xff); }
+  int lookChar() override
+    { return (bufPtr >= bufEnd && !fillBuf()) ? EOF : (*bufPtr & 0xff); }
+  Goffset getPos() override { return bufPos + (bufPtr - buf); }
+  void setPos(Goffset pos, int dir = 0) override;
+  Goffset getStart() override { return start; }
+  void moveStart(Goffset delta) override;
+
+  int getUnfilteredChar() override { return getChar(); }
+  void unfilteredReset() override { reset(); }
+
+protected:
+
+  Goffset start;
+  bool limited;
+
+private:
+
+  bool fillBuf();
+
+  bool hasGetChars() override { return true; }
+  int getChars(int nChars, unsigned char *buffer) override;
+
+  virtual Goffset currentPos() const = 0;
+  virtual void setCurrentPos(Goffset offset) = 0;
+  virtual Goffset read(char *buf, Goffset size) = 0;
+
+  static constexpr int seekInputStreamBufSize = 1024;
+  char buf[seekInputStreamBufSize];
+  char *bufPtr;
+  char *bufEnd;
+  Goffset bufPos;
+  Goffset savePos;
+  bool saved;
+};
+
 //------------------------------------------------------------------------
 // FilterStream
 //
@@ -336,7 +394,7 @@ class FilterStream: public Stream {
 public:
 
   FilterStream(Stream *strA);
-  ~FilterStream();
+  ~FilterStream() override;
   void close() override;
   Goffset getPos() override { return str->getPos(); }
   void setPos(Goffset pos, int dir = 0) override;
@@ -452,7 +510,7 @@ public:
 
   FileStream(GooFile* fileA, Goffset startA, bool limitedA,
 	     Goffset lengthA, Object &&dictA);
-  ~FileStream();
+  ~FileStream() override;
   BaseStream *copy() override;
   Stream *makeSubStream(Goffset startA, bool limitedA,
 				Goffset lengthA, Object &&dictA) override;
@@ -527,7 +585,7 @@ public:
 
   CachedFileStream(CachedFile *ccA, Goffset startA, bool limitedA,
 	     Goffset lengthA, Object &&dictA);
-  ~CachedFileStream();
+  ~CachedFileStream() override;
   BaseStream *copy() override;
   Stream *makeSubStream(Goffset startA, bool limitedA,
 				Goffset lengthA, Object &&dictA) override;
@@ -680,7 +738,7 @@ public:
    : BaseMemStream(bufA, startA, lengthA, std::move(dictA))
    { }
 
-  ~AutoFreeMemStream()
+  ~AutoFreeMemStream() override
     { gfree(buf); }
 };
 
@@ -699,7 +757,7 @@ class EmbedStream: public BaseStream {
 public:
 
   EmbedStream(Stream *strA, Object &&dictA, bool limitedA, Goffset lengthA, bool reusableA = false);
-  ~EmbedStream();
+  ~EmbedStream() override;
   BaseStream *copy() override;
   Stream *makeSubStream(Goffset start, bool limitedA,
 				Goffset lengthA, Object &&dictA) override;
@@ -743,7 +801,7 @@ class ASCIIHexStream: public FilterStream {
 public:
 
   ASCIIHexStream(Stream *strA);
-  ~ASCIIHexStream();
+  ~ASCIIHexStream() override;
   StreamKind getKind() const override { return strASCIIHex; }
   void reset() override;
   int getChar() override
@@ -766,7 +824,7 @@ class ASCII85Stream: public FilterStream {
 public:
 
   ASCII85Stream(Stream *strA);
-  ~ASCII85Stream();
+  ~ASCII85Stream() override;
   StreamKind getKind() const override { return strASCII85; }
   void reset() override;
   int getChar() override
@@ -792,7 +850,7 @@ public:
 
   LZWStream(Stream *strA, int predictor, int columns, int colors,
 	    int bits, int earlyA);
-  ~LZWStream();
+  ~LZWStream() override;
   StreamKind getKind() const override { return strLZW; }
   void reset() override;
   int getChar() override;
@@ -851,7 +909,7 @@ class RunLengthStream: public FilterStream {
 public:
 
   RunLengthStream(Stream *strA);
-  ~RunLengthStream();
+  ~RunLengthStream() override;
   StreamKind getKind() const override { return strRunLength; }
   void reset() override;
   int getChar() override
@@ -886,7 +944,7 @@ public:
   CCITTFaxStream(Stream *strA, int encodingA, bool endOfLineA,
 		 bool byteAlignA, int columnsA, int rowsA,
 		 bool endOfBlockA, bool blackA, int damagedRowsBeforeErrorA);
-  ~CCITTFaxStream();
+  ~CCITTFaxStream() override;
   StreamKind getKind() const override { return strCCITTFax; }
   void reset() override;
   int getChar() override
@@ -972,7 +1030,7 @@ class DCTStream: public FilterStream {
 public:
 
   DCTStream(Stream *strA, int colorXformA, Dict *dict, int recursion);
-  virtual ~DCTStream();
+  ~DCTStream() override;
   StreamKind getKind() const override { return strDCT; }
   void reset() override;
   void close() override;
@@ -1080,7 +1138,7 @@ public:
 
   FlateStream(Stream *strA, int predictor, int columns,
 	      int colors, int bits);
-  ~FlateStream();
+  ~FlateStream() override;
   StreamKind getKind() const override { return strFlate; }
   void reset() override;
   int getChar() override;
@@ -1154,7 +1212,7 @@ class EOFStream: public FilterStream {
 public:
 
   EOFStream(Stream *strA);
-  ~EOFStream();
+  ~EOFStream() override;
   StreamKind getKind() const override { return strWeird; }
   void reset() override {}
   int getChar() override { return EOF; }
@@ -1171,7 +1229,7 @@ class BufStream: public FilterStream {
 public:
 
   BufStream(Stream *strA, int bufSizeA);
-  ~BufStream();
+  ~BufStream() override;
   StreamKind getKind() const override { return strWeird; }
   void reset() override;
   int getChar() override;
@@ -1196,7 +1254,7 @@ class FixedLengthEncoder: public FilterStream {
 public:
 
   FixedLengthEncoder(Stream *strA, int lengthA);
-  ~FixedLengthEncoder();
+  ~FixedLengthEncoder() override;
   StreamKind getKind() const override { return strWeird; }
   void reset() override;
   int getChar() override;
@@ -1219,7 +1277,7 @@ class ASCIIHexEncoder: public FilterStream {
 public:
 
   ASCIIHexEncoder(Stream *strA);
-  ~ASCIIHexEncoder();
+  ~ASCIIHexEncoder() override;
   StreamKind getKind() const override { return strWeird; }
   void reset() override;
   int getChar() override
@@ -1249,7 +1307,7 @@ class ASCII85Encoder: public FilterStream {
 public:
 
   ASCII85Encoder(Stream *strA);
-  ~ASCII85Encoder();
+  ~ASCII85Encoder() override;
   StreamKind getKind() const override { return strWeird; }
   void reset() override;
   int getChar() override
@@ -1279,7 +1337,7 @@ class RunLengthEncoder: public FilterStream {
 public:
 
   RunLengthEncoder(Stream *strA);
-  ~RunLengthEncoder();
+  ~RunLengthEncoder() override;
   StreamKind getKind() const override { return strWeird; }
   void reset() override;
   int getChar() override
@@ -1315,7 +1373,7 @@ class LZWEncoder: public FilterStream {
 public:
 
   LZWEncoder(Stream *strA);
-  ~LZWEncoder();
+  ~LZWEncoder() override;
   StreamKind getKind() const override { return strWeird; }
   void reset() override;
   int getChar() override;
@@ -1347,7 +1405,7 @@ class CMYKGrayEncoder: public FilterStream {
 public:
 
   CMYKGrayEncoder(Stream *strA);
-  ~CMYKGrayEncoder();
+  ~CMYKGrayEncoder() override;
   StreamKind getKind() const override { return strWeird; }
   void reset() override;
   int getChar() override
@@ -1376,7 +1434,7 @@ class RGBGrayEncoder: public FilterStream {
 public:
 
   RGBGrayEncoder(Stream *strA);
-  ~RGBGrayEncoder();
+  ~RGBGrayEncoder() override;
   StreamKind getKind() const override { return strWeird; }
   void reset() override;
   int getChar() override
