@@ -7,13 +7,14 @@
  * Copyright (C) 2012 Koji Otani <sho@bbr.jp>
  * Copyright (C) 2012, 2013 Thomas Freitag <Thomas.Freitag@alfa.de>
  * Copyright (C) 2012 Fabio D'Urso <fabiodurso@hotmail.it>
- * Copyright (C) 2014, 2018 Adam Reichold <adam.reichold@t-online.de>
+ * Copyright (C) 2014, 2018, 2020 Adam Reichold <adam.reichold@t-online.de>
  * Copyright (C) 2015 William Bader <williambader@hotmail.com>
  * Copyright (C) 2016 Jakub Alba <jakubalba@gmail.com>
  * Copyright (C) 2017 Adrian Johnson <ajohnson@redneon.com>
  * Copyright (C) 2017 Suzuki Toshiya <mpsuzuki@hiroshima-u.ac.jp>
  * Copyright (C) 2018 Klarälvdalens Datakonsult AB, a KDAB Group company, <info@kdab.com>. Work sponsored by the LiMux project of the city of Munich
  * Copyright (C) 2019 Oliver Sander <oliver.sander@tu-dresden.de>
+ * Copyright (C) 2019 Alexander Volkov <a.volkov@rusbitech.ru>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -57,9 +58,6 @@
 
 namespace Poppler {
 
-  int DocumentData::count = 0;
-  QMutex DocumentData::mutex;
-
   Document *Document::load(const QString &filePath, const QByteArray &ownerPassword,
 			   const QByteArray &userPassword)
     {
@@ -69,6 +67,15 @@ namespace Poppler {
 	return DocumentData::checkDocument(doc);
     }
 
+	Document *Document::load(QIODevice *device, const QByteArray &ownerPassword,
+			   const QByteArray &userPassword)
+    {
+	DocumentData *doc = new DocumentData(device,
+					     new GooString(ownerPassword.data()),
+					     new GooString(userPassword.data()));
+	return DocumentData::checkDocument(doc);
+    }
+
     Document *Document::loadFromData(const QByteArray &fileContents,
 			      const QByteArray &ownerPassword,
 			      const QByteArray &userPassword)
@@ -139,7 +146,12 @@ namespace Poppler {
 					new GooString(ownerPassword.data()),
 					new GooString(userPassword.data()));
 	    }
-	    else
+	    else if (m_doc->m_device)
+	    {
+		doc2 = new DocumentData(m_doc->m_device,
+					new GooString(ownerPassword.data()),
+					new GooString(userPassword.data()));
+	    }
 	    {
 		doc2 = new DocumentData(m_doc->m_filePath,
 					new GooString(ownerPassword.data()),
@@ -806,8 +818,8 @@ namespace Poppler {
 
         Form *form = m_doc->doc->getCatalog()->getForm();
         const std::vector<Ref> &calculateOrder = form->getCalculateOrder();
-        for (uint i = 0; i < calculateOrder.size(); ++i) {
-            FormWidget *w = form->findWidgetByRef(calculateOrder[i]);
+        for (Ref r : calculateOrder) {
+            FormWidget *w = form->findWidgetByRef(r);
             if (w) {
                 result << w->getID();
             }
