@@ -126,7 +126,7 @@ class LinkSoundPrivate : public LinkPrivate
 {
 	public:
 		LinkSoundPrivate( const QRectF &area );
-		~LinkSoundPrivate();
+		~LinkSoundPrivate() override;
 
 		double volume;
 		bool sync : 1;
@@ -148,8 +148,8 @@ class LinkSoundPrivate : public LinkPrivate
 class LinkRenditionPrivate : public LinkPrivate
 {
 	public:
-		LinkRenditionPrivate( const QRectF &area, ::MediaRendition *rendition, ::LinkRendition::RenditionOperation operation, const QString &script, const Ref annotationReference );
-		~LinkRenditionPrivate();
+		LinkRenditionPrivate( const QRectF &area, ::MediaRendition *rendition, ::LinkRendition::RenditionOperation operation, const QString &script, const Ref ref );
+		~LinkRenditionPrivate() override;
 
 		MediaRendition *rendition;
 		LinkRendition::RenditionAction action;
@@ -434,7 +434,7 @@ class LinkMoviePrivate : public LinkPrivate
 		: Link( *new LinkGotoPrivate( linkArea, destination ) )
 	{
 		Q_D( LinkGoto );
-		d->extFileName = extFileName;
+		d->extFileName = std::move(extFileName); // TODO remove when extFileName moves to be a const &
 	}
 	
 	LinkGoto::~LinkGoto()
