@@ -1,7 +1,7 @@
 /* poppler-private.h: qt interface to poppler
  * Copyright (C) 2005, Net Integration Technologies, Inc.
  * Copyright (C) 2005, 2008, Brad Hards <bradh@frogmouth.net>
- * Copyright (C) 2006-2009, 2011, 2012, 2017, 2018 by Albert Astals Cid <aacid@kde.org>
+ * Copyright (C) 2006-2009, 2011, 2012, 2017-2019 by Albert Astals Cid <aacid@kde.org>
  * Copyright (C) 2007-2009, 2011, 2014 by Pino Toscano <pino@kde.org>
  * Copyright (C) 2011 Andreas Hartmetz <ahartmetz@gmail.com>
  * Copyright (C) 2011 Hib Eris <hib@hiberis.nl>
@@ -12,9 +12,11 @@
  * Copyright (C) 2016 Jakub Alba <jakubalba@gmail.com>
  * Copyright (C) 2017 Christoph Cullmann <cullmann@kde.org>
  * Copyright (C) 2018 Klarälvdalens Datakonsult AB, a KDAB Group company, <info@kdab.com>. Work sponsored by the LiMux project of the city of Munich
- * Copyright (C) 2018 Adam Reichold <adam.reichold@t-online.de>
+ * Copyright (C) 2018, 2020 Adam Reichold <adam.reichold@t-online.de>
  * Copyright (C) 2019 Oliver Sander <oliver.sander@tu-dresden.de>
  * Copyright (C) 2019 João Netto <joaonetto901@gmail.com>
+ * Copyright (C) 2019 Jan Grulich <jgrulich@redhat.com>
+ * Copyright (C) 2019 Alexander Volkov <a.volkov@rusbitech.ru>
  * Inspired on code by
  * Copyright (C) 2004 by Albert Astals Cid <tsdgeos@terra.es>
  * Copyright (C) 2004 by Enrico Ros <eros.kde@email.it>
@@ -45,6 +47,7 @@
 #include <config.h>
 #include <GfxState.h>
 #include <GlobalParams.h>
+#include <Form.h>
 #include <PDFDoc.h>
 #include <FontInfo.h>
 #include <OutputDev.h>
@@ -55,6 +58,7 @@
 
 #include "poppler-qt5.h"
 #include "poppler-embeddedfile-private.h"
+#include "poppler-qiodeviceinstream-private.h"
 
 class LinkDest;
 class FormWidget;
@@ -73,7 +77,7 @@ namespace Poppler {
 
     GooString *QDateTimeToUnicodeGooString(const QDateTime &dt);
 
-    void qt5ErrorFunction(int pos, char *msg, va_list args);
+    void qt5ErrorFunction(ErrorCategory /*category*/, Goffset pos, const char *msg);
 
     Annot::AdditionalActionsType toPopplerAdditionalActionType(Annotation::AdditionalActionType type);
 
@@ -91,11 +95,13 @@ namespace Poppler {
             bool externalDest;
     };
 
-    class DocumentData {
+    class DocumentData : private GlobalParamsIniter {
     public:
-	DocumentData(const QString &filePath, GooString *ownerPassword, GooString *userPassword)
+	DocumentData(const QString &filePath, GooString *ownerPassword, GooString *userPassword) :
+	GlobalParamsIniter(qt5ErrorFunction)
 	    {
 		init();
+		m_device = nullptr;
 		m_filePath = filePath;	
 
 #ifdef _WIN32
@@ -109,8 +115,21 @@ namespace Poppler {
 		delete userPassword;
 	    }
 	
-	DocumentData(const QByteArray &data, GooString *ownerPassword, GooString *userPassword)
+	DocumentData(QIODevice *device, GooString *ownerPassword, GooString *userPassword) :
+	GlobalParamsIniter(qt5ErrorFunction)
 	    {
+		m_device = device;
+		QIODeviceInStream *str = new QIODeviceInStream(device, 0, false, device->size(), Object(objNull));
+		init();
+		doc = new PDFDoc(str, ownerPassword, userPassword);
+		delete ownerPassword;
+		delete userPassword;
+	    }
+
+	DocumentData(const QByteArray &data, GooString *ownerPassword, GooString *userPassword) :
+	GlobalParamsIniter(qt5ErrorFunction)
+	    {
+		m_device = nullptr;
 		fileContents = data;
 		MemStream *str = new MemStream((char*)fileContents.data(), 0, fileContents.length(), Object(objNull));
 		init();
@@ -149,6 +168,7 @@ namespace Poppler {
 
 	PDFDoc *doc;
 	QString m_filePath;
+	QIODevice *m_device;
 	QByteArray fileContents;
 	bool locked;
 	Document::RenderBackend m_backend;
@@ -156,8 +176,6 @@ namespace Poppler {
 	QPointer<OptContentModel> m_optContentModel;
 	QColor paperColor;
 	int m_hints;
-	static int count;
-	static QMutex mutex;
     };
 
     class FontInfoData
@@ -174,6 +192,7 @@ namespace Poppler {
 		{
 			if (fi->getName()) fontName = fi->getName()->c_str();
 			if (fi->getFile()) fontFile = fi->getFile()->c_str();
+			if (fi->getSubstituteName()) fontSubstituteName = fi->getSubstituteName()->c_str();
 			isEmbedded = fi->getEmbedded();
 			isSubset = fi->getSubset();
 			type = (Poppler::FontInfo::Type)fi->getType();
@@ -184,6 +203,7 @@ namespace Poppler {
 		FontInfoData& operator=(const FontInfoData &) = default;
 
 		QString fontName;
+		QString fontSubstituteName;
 		QString fontFile;
 		bool isEmbedded : 1;
 		bool isSubset : 1;
@@ -237,13 +257,14 @@ namespace Poppler {
 		::Page *page;
 		::FormWidget *fm;
 		QRectF box;
+		static POPPLER_QT5_EXPORT ::FormWidget *getFormWidget( const FormField *f );
     };
     
     class FormFieldIcon;
     class FormFieldIconData
     {
     public:
-    	static FormFieldIconData *getData( const FormFieldIcon &f );
+    	static POPPLER_QT5_EXPORT FormFieldIconData *getData( const FormFieldIcon &f );
     	Dict *icon;
     };
 
